Name:		orc
Version:	0.4.17
Release:	1
Summary:	The Oil Run-time Compiler
Group:		System Environment/Libraries
License:	BSD
URL:		http://code.entropywave.com/projects/orc/
Source0:	http://code.entropywave.com/download/orc/%{name}-%{version}.tar.gz
Patch0:		%{name}-%{version}-aix.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

BuildRequires:	libtool, make
BuildRequires:	gcc >= 4.2.3-2
Requires:	libgcc >= 4.2.3-2

%define _libdir64 %{_prefix}/lib64

%description
Orc is a library and set of tools for compiling and executing
very simple programs that operate on arrays of data.  The "language"
is a generic assembly language that represents many of the features
available in SIMD architectures, including saturated addition and
subtraction, and many arithmetic operations.

The library is available as 32-bit and 64-bit.


%package doc
Summary:	Documentation for Orc
Group:		Development/Languages
Requires:	%{name} = %{version}-%{release}

%description doc
Documentation for Orc.


%package devel
Summary:	Development files and static libraries for Orc
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	%{name}-compiler
Requires:	pkg-config

%description devel
This package contains the files needed to build packages that depend
on orc.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc -q64" or "gcc -maix64".


%package compiler
Summary:	Orc compiler
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	pkg-config

%description compiler
The Orc compiler, to produce optimized code.


%prep
%setup -q 
%patch0
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
# setup GNU GCC build environment
export CFLAGS="-pthread -DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -D_ALL_SOURCE -DFUNCPROTO=15 -O -I/opt/freeware/include"

export LD=ld
export LDFLAGS="-L/opt/freeware/lib"

cd 64bit
# first build the 64-bit version
# on purpose we configure the "--build=powerpc-ibm-aix5.1.0.0" option
# differently from what config.guess provides
export CC="gcc -maix64 -mcpu=power3"
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --build=ibm-aix5.1.0.0 \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --enable-shared --disable-static
gmake %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
# on purpose we configure the "--build=powerpc-ibm-aix5.1.0.0" option
# differently from what config.guess provides
export CC="gcc -maix32 -mcpu=power3"
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --build=ibm-aix5.1.0.0 \
    --prefix=%{_prefix} \
    --enable-shared --disable-static
gmake %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
gmake DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
gmake DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/liborc-0.4.a ${RPM_BUILD_ROOT}%{_libdir64}/liborc-0.4.so.0
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/liborc-test-0.4.a ${RPM_BUILD_ROOT}%{_libdir64}/liborc-test-0.4.so.0

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/COPYING 32bit/README
%{_bindir}/orc-bugreport*
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
/usr/bin/orc-bugreport*
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files doc
%defattr(-,root,system,-)
%doc %{_datadir}/gtk-doc/html/orc/


%files devel
%defattr(-,root,system,-)
%doc 32bit/examples/*.c
%{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/*.pc
%{_libdir64}/pkgconfig/*.pc
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%files compiler
%defattr(-,root,system,-)
%{_bindir}/orcc*
/usr/bin/orcc*


%changelog
* Fri May 03 2013 Michael Perzl <michael@perzl.org> - 0.4.17-1
- updaed to version 0.4.17

* Thu Oct 06 2011 Michael Perzl <michael@perzl.org> - 0.4.16-1
- updaed to version 0.4.16

* Sat Apr 30 2011 Michael Perzl <michael@perzl.org> - 0.4.14-1
- updaed to version 0.4.14

* Tue Apr 26 2011 Michael Perzl <michael@perzl.org> - 0.4.12-1
- updaed to version 0.4.12

* Thu Jan 13 2011 Michael Perzl <michael@perzl.org> - 0.4.11-1
- first version for AIX5L v5.1 and higher
